==> 0.0.1.tar.gz: lib/widgets/spark_select.dart <==
part of spark_widget;

class SparkSelect extends StatelessWidget {
  const SparkSelect({
    Key? key,
    required this.manage,
    required this.options,
    this.itemBuilder,
    this.itemSpacing,
    this.itemSize,
    this.selectedDecoration,
    this.unSelectedDecoration,
  }) : super(key: key);

  final FormItemManage manage;

  final List<SparkSelectOption> options;

  final ItemValueBuilder? itemBuilder;

  /// item space
  final double? itemSpacing;

  final Size? itemSize;

  final SparkSelectDecoration? selectedDecoration;

  final SparkSelectDecoration? unSelectedDecoration;

  Widget _buildOption(
    BuildContext context,
    SparkSelectOption option,
    String value,
    ValueUpdater updater,
    SparkTheme? theme,
  ) {
    bool _isChecked = option.value == value;
    return GestureDetector(
      onTap: () {
        updater(option.value);
      },
      child: itemBuilder != null
          ? itemBuilder!(context, option)
          : _buildDefaultOption(context, option.label, _isChecked, theme),
    );
  }

  Widget _buildDefaultOption(BuildContext context, String optionName,
      bool isChecked, SparkTheme? theme) {
    Size _optionSize = itemSize ?? theme?.selectItemSize ?? const Size(76, 30);
    SparkSelectDecoration _decoration = isChecked
        ? (selectedDecoration ?? theme!.selectedItemDecoration!)
        : (unSelectedDecoration ?? theme!.unSelectedItemDecoration!);
    return Container(
      constraints: BoxConstraints(
          maxWidth: _optionSize.width, minHeight: _optionSize.height),
      alignment: Alignment.center,
      decoration: BoxDecoration(
        color: _decoration.backgroundColor,
        borderRadius: _decoration.borderRadius,
        border: _decoration.border,
      ),
      child: Text(
        optionName,
        style: TextStyle(
          color: _decoration.textColor,
          fontSize: _decoration.fontSize,
          fontWeight: _decoration.fontWeight,
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    SparkTheme? _theme = SparkThemeData.of(context);
    return SparkWrapper(
      manage: manage,
      builder: (_, _value, _updater) {
        return Wrap(
          spacing: 10,
          children: [
            for (SparkSelectOption _item in options)
              _buildOption(context, _item, _value, _updater, _theme)
          ],
        );
      },
    );
  }
}

class SparkSelectOption extends SparkOption {
  SparkSelectOption.form(String label, String value, {this.data})
      : super(label, value);

  final dynamic data;
}

class SparkSelectDecoration {
  const SparkSelectDecoration({
    this.fontWeight,
    this.textColor,
    this.borderRadius,
    this.fontSize,
    this.backgroundColor,
    this.border,
  });

  SparkSelectDecoration copyWith({
    FontWeight? fontWeight,
    Color? textColor,
    BorderRadiusGeometry? borderRadius,
    double? fontSize,
    Color? backgroundColor,
    BoxBorder? border,
  }) {
    return SparkSelectDecoration(
      fontWeight: fontWeight ?? this.fontWeight,
      textColor: textColor ?? this.textColor,
      borderRadius: borderRadius ?? this.borderRadius,
      fontSize: fontSize ?? this.fontSize,
      backgroundColor: backgroundColor ?? this.backgroundColor,
      border: border ?? this.border,
    );
  }

  final FontWeight? fontWeight;
  final Color? textColor;
  final BorderRadiusGeometry? borderRadius;
  final double? fontSize;
  final Color? backgroundColor;
  final BoxBorder? border;
}

==> 0.0.2.tar.gz: lib/widgets/spark_select.dart <==
part of spark_widget;

class SparkSelect extends SparkFormStateLessWidget<String> {
  const SparkSelect({
    Key? key,
    required FormItemManage manage,
    required this.options,
    this.itemBuilder,
    this.itemSpacing,
    this.itemSize,
    this.selectedDecoration,
    this.unSelectedDecoration,
  }) : super(key: key, manage: manage);

  final List<SparkSelectOption> options;

  final ItemValueBuilder? itemBuilder;

  /// item space
  final double? itemSpacing;

  final Size? itemSize;

  final SparkSelectDecoration? selectedDecoration;

  final SparkSelectDecoration? unSelectedDecoration;

  Widget _buildOption(
    BuildContext context,
    SparkSelectOption option,
    String value,
    ValueUpdater updater,
    SparkTheme? theme,
  ) {
    bool _isChecked = option.value == value;
    return GestureDetector(
      onTap: () {
        // updater(option.value);
        handleFormDataChange(context, option.value);
      },
      child: itemBuilder != null
          ? itemBuilder!(context, option)
          : _buildDefaultOption(context, option.label, _isChecked, theme),
    );
  }

  Widget _buildDefaultOption(BuildContext context, String optionName,
      bool isChecked, SparkTheme? theme) {
    Size _optionSize = itemSize ?? theme?.selectItemSize ?? const Size(76, 30);
    SparkSelectDecoration _decoration = isChecked
        ? (selectedDecoration ?? theme!.selectedItemDecoration!)
        : (unSelectedDecoration ?? theme!.unSelectedItemDecoration!);
    return Container(
      constraints: BoxConstraints(
          maxWidth: _optionSize.width, minHeight: _optionSize.height),
      alignment: Alignment.center,
      decoration: BoxDecoration(
        color: _decoration.backgroundColor,
        borderRadius: _decoration.borderRadius,
        border: _decoration.border,
      ),
      child: Text(
        optionName,
        style: TextStyle(
          color: _decoration.textColor,
          fontSize: _decoration.fontSize,
          fontWeight: _decoration.fontWeight,
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    SparkTheme? _theme = SparkThemeData.of(context);
    return SparkWrapper(
      manage: manage,
      builder: (_, _value, _updater) {
        return Wrap(
          spacing: itemSpacing ?? 10,
          children: [
            for (SparkSelectOption _item in options)
              _buildOption(context, _item, _value, _updater, _theme)
          ],
        );
      },
    );
  }
}

class SparkSelectOption extends SparkOption {
  SparkSelectOption.form(String label, String value, {this.data})
      : super(label, value);

  final dynamic data;
}

class SparkSelectDecoration {
  const SparkSelectDecoration({
    this.fontWeight,
    this.textColor,
    this.borderRadius,
    this.fontSize,
    this.backgroundColor,
    this.border,
  });

  SparkSelectDecoration copyWith({
    FontWeight? fontWeight,
    Color? textColor,
    BorderRadiusGeometry? borderRadius,
    double? fontSize,
    Color? backgroundColor,
    BoxBorder? border,
  }) {
    return SparkSelectDecoration(
      fontWeight: fontWeight ?? this.fontWeight,
      textColor: textColor ?? this.textColor,
      borderRadius: borderRadius ?? this.borderRadius,
      fontSize: fontSize ?? this.fontSize,
      backgroundColor: backgroundColor ?? this.backgroundColor,
      border: border ?? this.border,
    );
  }

  final FontWeight? fontWeight;
  final Color? textColor;
  final BorderRadiusGeometry? borderRadius;
  final double? fontSize;
  final Color? backgroundColor;
  final BoxBorder? border;
}
